macro_rules! expr {
($($v:tt)*) => { ... };
}Expand description
Create a boxed Expression trait object from a given Value.
Supports the same format as the value macro.
macro_rules! expr {
($($v:tt)*) => { ... };
}Create a boxed Expression trait object from a given Value.
Supports the same format as the value macro.